@@ -51,6 +51,7 @@ static void         html_box_accessible_remove_focus_handler     (AtkComponent
                                                                   guint             handler_id);
 static gboolean     is_box_showing                               (HtmlBox           *box);
 
+static char* view_str = "view";
 static AtkGObjectAccessibleClass *parent_class = NULL;
 
 GType
@@ -156,13 +157,13 @@ html_box_accessible_initialize (AtkObject *obj, gpointer data)
 			
 		 } else
 			parent = box->parent;
-		data = g_object_get_data (G_OBJECT (parent), "view");
+		data = g_object_get_data (G_OBJECT (parent), view_str);
 		if (data)
-			g_object_set_data (G_OBJECT (box), "view", data);
+			g_object_set_data (G_OBJECT (box), view_str, data);
 		else {
-			data = g_object_get_data (G_OBJECT (box), "view");
+			data = g_object_get_data (G_OBJECT (box), view_str);
 			g_assert (data);
-			g_object_set_data (G_OBJECT (parent), "view", data);
+			g_object_set_data (G_OBJECT (parent), view_str, data);
 		}
 		parent_obj = atk_gobject_accessible_for_object (G_OBJECT (parent));
 		atk_object_set_parent (obj, parent_obj);
@@ -328,7 +329,7 @@ html_box_accessible_get_parent (AtkObject *obj)
 
 		g_obj = atk_gobject_accessible_get_object (atk_gobj);
 		if (g_obj != NULL) {
-			widget = g_object_get_data (g_obj, "view");
+			widget = g_object_get_data (g_obj, view_str);
 			box = HTML_BOX (g_obj);
 			g_return_val_if_fail (!box->parent, NULL); 
 			g_return_val_if_fail (widget, NULL); 
@@ -465,8 +466,20 @@ GtkWidget*
 html_box_accessible_get_view_widget (HtmlBox *box)
 {
 	GtkWidget *widget;
+	HtmlBox *temp_box;
 	
-	widget = g_object_get_data (G_OBJECT (box), "view");
+	temp_box = box;
+	widget = g_object_get_data (G_OBJECT (temp_box), view_str);
+	/*
+	 * If box has not have an accessible object created then the data
+	 * will not have been set so try the box's parent. This will work
+	 * as some box must have had an accessible created for this function
+	 * to be called.
+	 */
+	while (!widget) {
+		temp_box = temp_box->parent;
+		widget = g_object_get_data (G_OBJECT (temp_box), view_str);
+	}
 	return widget;
 }
 
