@@ -230,7 +230,7 @@ css_parser_parse_string (const gchar *str, gint start_pos, gint end_pos, gchar *
 		else if (c == '\\') {
 			gunichar unicode;
 	  
-			pos = css_parser_parse_escape (str, pos, end_pos, &unicode);
+			pos = css_parser_parse_escape (str, pos -1, end_pos, &unicode);
 			if (pos < 0)
 				return -1;
 		
@@ -246,9 +246,11 @@ css_parser_parse_string (const gchar *str, gint start_pos, gint end_pos, gchar *
 			}
 		}
 		else if (c > 0x80) {
-			g_warning ("support unicode!\n");
-			g_free (buffer);
-			return -1;
+			if (!has_escape) {
+				if (buffer_size == buffer_size_max)
+					buffer = g_realloc (buffer, (buffer_size_max <<= 1));
+				buffer[buffer_size++] = c;
+			}
 		}
 		else {
 			g_free (buffer);
@@ -472,14 +474,26 @@ css_parser_parse_term (const gchar *buffer, gint start_pos, gint end_pos, CssVal
 		/* Check if we have a function */
 		if (buffer[pos] == '(') {
 			gint func_end = css_parser_parse_to_char (buffer, ')', pos + 1, end_pos);
+			gint save_pos = pos;
 			CssValue *val;
 
 			if (func_end == end_pos) {
 				return -1;
 			}
 			
-			pos = css_parser_parse_value (buffer, pos + 1, func_end, &val);
+			pos = css_parser_parse_value (buffer, save_pos + 1, func_end, &val);
 
+			if (pos == -1) {
+				/*
+				 * If it is not a value just store as string
+				 */
+				gchar *str;
+
+				str = g_strndup (buffer + save_pos + 1, func_end - save_pos - 1);
+				val = css_value_string_new (str);
+				g_free (str);
+				pos = func_end;
+			}
 			if (pos != -1) {
 				if (ret_val) 
 					*ret_val = css_value_function_new (atom, val);
@@ -487,7 +501,6 @@ css_parser_parse_term (const gchar *buffer, gint start_pos, gint end_pos, CssVal
 					css_value_unref (val);
 			}
 
-
 			/* This is due to the ) */
 			pos++; 
 		}
