@@ -23,6 +23,7 @@
 #include <gtk/gtk.h>
 #include <string.h>
 #include <ctype.h>
+#include <locale.h>
 
 /* FIXME: Don't include htmlgdkpainter.h */
 #include "graphics/htmlgdkpainter.h"
@@ -141,12 +142,18 @@ html_box_text_finalize (GObject *self)
 {
 	HtmlBoxText *text = HTML_BOX_TEXT (self);
 	HtmlBoxTextMaster *master;
+	HtmlBox *box;
 
 	master = text->master;
 	if (master) {
 		html_box_text_free_master (master);
 		g_free (master);
 		text->master = NULL;
+	} else {
+		box = HTML_BOX (self);
+
+		if (box->dom_node)
+			g_object_remove_weak_pointer (G_OBJECT (box->dom_node), (gpointer *) &(box->dom_node));
 	}
 
 	if (text->glyphs) {
@@ -343,6 +350,7 @@ html_box_text_recalc_items (HtmlBoxText *text,
 	guchar *canon_text, *canon_end;
 	PangoGlyphString *glyphs;
 	int orig_len;
+	char *ctype;
 
 	master = text->master;
 
@@ -358,8 +366,25 @@ html_box_text_recalc_items (HtmlBoxText *text,
 	/* FIXME: The context should be stored somewhere in the view tree */
 	if (context == NULL) {
 		context = gdk_pango_context_get ();
+
 		/* FIXME: This should be set from the document */
-		pango_context_set_language (context, pango_language_from_string ("fr")); 
+
+		/* modified by phill.zhang@sun.com, borrow form fontconfig */
+                ctype = setlocale (LC_CTYPE, NULL);
+                if (!ctype || !strcmp (ctype, "C"))
+                {
+                    ctype = getenv ("LC_ALL");
+                    if (!ctype)
+                    {
+                        ctype = getenv ("LC_CTYPE");
+                        if (!ctype)
+                            ctype = getenv ("LANG");
+                    }
+                }
+                if (!ctype || !strcmp(ctype, "C") || !strcmp(ctype, "POSIX"))
+		    pango_context_set_language (context, pango_language_from_string ("en")); 
+                else
+		    pango_context_set_language (context, pango_language_from_string (ctype)); 
 	}
 	
 	if (white_space == HTML_WHITE_SPACE_PRE) {
